


GRAPH_COLLIDER_CONFIG = {"password":"jebBj8iyfcGQt7iaPcXEtSPyMZSV6NFB",
                         "host":"redis-15521.c6721.us-east-1-mz.ec2.cloud.rlrcp.com",
                         "port":"15521",
                         "delays":[55],
                         "max_ttl":5*60,
                         "transactions_ttl":5*60,
                         "num_predictions":1000,
                         "obscurity":"gc-obscure"}

REDIZ_TEST_CONFIG = {"password":"5r70RHtd2m0x3BHdLE8mp7APxoIJS1aH",
                     "host":"redis-19709.c11.us-east-1-3.ec2.cloud.redislabs.com",
                     "port":"19709",
                     "delays": [1, 5],
                     "obscurity": "0e4da9eb-obscurity-testing-only-e07adfersadfdf893c"
                     }


REDIZ_CONFIG = GRAPH_COLLIDER_CONFIG